@@ -31,6 +31,7 @@ from calculate.lib.utils.common import getUserPrimaryGroup
 from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.utils.device import getUdevDeviceInfo
 from crypt import crypt
+from autopartition import SchemeOpt, SchemeDevices
 from calculate.lib.encrypt import encrypt
 import calculate.lib.cl_ini_parser as cl_ini_parser
 
@@ -445,9 +446,10 @@ class VariableClInstallDevFrom(Variable):
 
     def get(self):
         if (self.Get('cl_autopartition_set') == 'on' and
-                    "root" in self.Get('cl_autopartition_scheme')):
+                    SchemeOpt.Update in self.Get('cl_autopartition_scheme')):
             return self.Select('cl_autopartition_disk_dev',
-                               where='cl_autopartition_disk_scheme', eq='root',
+                               where='cl_autopartition_disk_scheme',
+                               eq=SchemeDevices.Root2,
                                limit=1)
         return ""
 
